Learn R Programming

processmapR (version 0.3.3)

precedence_matrix: Precendence Matrix

Description

Construct a precendence matrix, showing how activities are followed by each other.

Usage

precedence_matrix(eventlog, type = c("absolute", "relative",
  "relative-antecedent", "relative-consequent", "relative-case"))

Arguments

eventlog

The event log object to be used

type

The type of precedence matrix, which can be absolulte, relative, relative-antecedent or relative-consequent. Absolute will return a matrix with absolute frequencies, relative will return global relative frequencies for all antecedent-consequent pairs. Relative-antecedent will return relative frequencies within each antecendent, i.e. showing the relative proportion of consequents within each antecedent. Relative-consequent will do the reverse.

Examples

Run this code
# NOT RUN {
library(eventdataR)
data(patients)
precedence_matrix(patients)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab