Learn R Programming

processmapR (version 0.2.0)

performance: Performance map profile

Description

Function to create a performance map profile to be used as the type of a process map. It results in a process map describing process time.

Usage

performance(FUN = mean, units = "days")

Arguments

FUN

A summary function to be called on the process time of a specific activity, e.g. mean, median, min, max

units

The time unit in which processing time should be presented (mins, hours, days, weeks)