powered by
Function to create a performance map profile to be used as the type of a process map. It results in a process map describing process time.
performance(FUN = mean, units = "days")
A summary function to be called on the process time of a specific activity, e.g. mean, median, min, max
The time unit in which processing time should be presented (mins, hours, days, weeks)