A function for creating a process map of an event log.
process_map(eventlog, type, sec, type_nodes, type_edges, sec_nodes, sec_edges,
rankdir, render, fixed_edge_width, fixed_node_pos, ...)# S3 method for eventlog
process_map(eventlog, type = frequency("absolute"),
sec = NULL, type_nodes = type, type_edges = type, sec_nodes = sec,
sec_edges = sec, rankdir = "LR", render = T, fixed_edge_width = F,
fixed_node_pos = NULL, ...)
The event log object for which to create a process map
A process map type, which can be created with the functions frequency, performance and custom. The first type focusses on the frequency aspect of a process, while the second one focussed on processing time. The third one allows custom attributes to be used.
A secondary process map type. Values are shown between brackets.
A process map type to be used for nodes only, which can be created with the functions frequency and performance. The first type focusses on the frequency aspect of a process, while the second one focussed on processing time.
A process map type to be used for edges only, which can be created with the functions frequency and performance. The first type focusses on the frequency aspect of a process, while the second one focussed on processing time.
A secondary process map type for nodes only.
A secondary process map type for edges only.
The direction in which to layout the graph: "LR" (default),"TB", "BT", "RL", corresponding to directed graphs drawn from top to bottom, from left to right, from bottom to top, and from right to left, respectively.
Whether the map should be rendered immediately (default), or rather an object of type dgr_graph should be returned.
If TRUE, don't vary the width of edges.
When specified as a data.frame with three columns 'act', 'x', and 'y' the position of nodes is fixed. Note that his can only be used with the 'neato' layout engine.
Deprecated arguments
eventlog: Process map for event log
# NOT RUN {
library(eventdataR)
data(patients)
process_map(patients)
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab