A function for creating a process map of an event log.
process_map(eventlog, type = frequency("absolute"), type_nodes = type,
type_edges = type, rankdir = "LR", render = T, fixed_edge_width = F,
...)The event log object for which to create a process map
A process map type, which can be created with the functions frequency and performance. The first type focusses on the frequency aspect of a process, while the second one focussed on processing time.
A process map type to be used for nodes only, which can be created with the functions frequency and performance. The first type focusses on the frequency aspect of a process, while the second one focussed on processing time.
A process map type to be used for edges only, which can be created with the functions frequency and performance. The first type focusses on the frequency aspect of a process, while the second one focussed on processing time.
The direction in which to layout the graph: "LR" (default),"TB", "BT", "RL", corresponding to directed graphs drawn from top to bottom, from left to right, from bottom to top, and from right to left, respectively.
Whether the map should be rendered immediately (default), or rather an object of type dgr_graph should be returned.
If TRUE, don't vary the width of edges.
Deprecated arguments
# NOT RUN {
library(eventdataR)
data(patients)
process_map(patients)
# }
Run the code above in your browser using DataLab