Learn R Programming

processmapR (version 0.2.0)

process_map: Process Map

Description

A function for creating a process map of an event log.

Usage

process_map(eventlog, type = frequency("absolute"), render = T)

Arguments

eventlog

The event log object for which to create a process map

type

A process map type, which can be created with the functions frequency and performance. The first type focusses on the frequency aspect of a process, while the second one focussed on processing time.

render

Whether the map should be rendered immediately (default), or rather an object of type dgr_graph should be returned.

Examples

Run this code
# NOT RUN {
library(eventdataR)
data(patients)
process_map(patients)
# }

Run the code above in your browser using DataLab