A function for creating a process map of an event log.
Usage
process_map(eventlog, type = frequency("absolute"), render = T)
Arguments
eventlog
The event log object for which to create a process map
type
A process map type, which can be created with the functions frequency and performance. The first type focusses on the frequency aspect of a process, while the second one focussed on processing time.
render
Whether the map should be rendered immediately (default), or rather an object of type dgr_graph should be returned.