Create process matrix
process_matrix(eventlog, type, ...)# S3 method for eventlog
process_matrix(eventlog, type = frequency(), ...)
The event log object for which to create a process matrix
A process matrix type, which can be created with the functions frequency, performance and custom. The first type focusses on the frequency aspect of a process, while the second one focussed on processing time. The third one allows custom attributes to be used.
Other arguments
eventlog: Process matrix for event log