A function for creating a resource map of an event log based on handover of work.
Usage
resource_map(eventlog, type = frequency("absolute"), render = T, ...)
Arguments
eventlog
The event log object for which to create a resource map
type
A process map type, which can be created with the functions frequency and performance. The first type focusses on the frequency aspect of a process, while the second one focussed on processing time.
render
Whether the map should be rendered immediately (default), or rather an object of type dgr_graph should be returned.