Learn R Programming

processmapR (version 0.2.0)

resource_map: Resource Map

Description

A function for creating a resource map of an event log based on handover of work.

Usage

resource_map(eventlog, render = T)

Arguments

eventlog

The event log object for which to create a resource map

render

Whether the map should be rendered immediately (default), or rather an object of type dgr_graph should be returned.

Examples

Run this code
# NOT RUN {
library(eventdataR)
data(patients)
resource_map(patients)
# }

Run the code above in your browser using DataLab