Learn R Programming

processmapR (version 0.2.0)

resource_matrix: Resource Matrix

Description

Construct a resource matrix, showing how work is handed over

Usage

resource_matrix(eventlog, type = c("absolute", "relative",
  "relative_antecedent", "relative_consequent"))

Arguments

eventlog

The event log object to be used

type

The type of resource matrix, which can be absolulte, relative, relative_antecedent or relative_consequent. Absolute will return a matrix with absolute frequencies, relative will return global relative frequencies for all antecedent-consequent pairs. Relative_antecedent will return relative frequencies within each antecendent, i.e. showing the relative proportion of consequents within each antecedent. Relative_consequent will do the reverse.

Examples

Run this code
# NOT RUN {
library(eventdataR)
data(patients)
precedence_matrix(patients)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab